@@ -69,7 +69,7 @@ struct _JOBPrivate {
 enum
 {
   PROP_0,
-  PROP_CONFIG,
+  PROP_CONFIG
 };
  
 
